==> haskell-bitarray-0.0.1.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bitarray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bitarray
version: 0.0.1.1
id: bitarray-0.0.1.1-7aLvtv6Zt0Q3riGztsfTFs
key: bitarray-0.0.1.1-7aLvtv6Zt0Q3riGztsfTFs
license: BSD3
copyright: (c) 2009 Balazs Komuves
maintainer: bkomuves (plus) hackage (at) gmail (dot) com
stability: Experimental
homepage: http://code.haskell.org/~bkomuves/
synopsis: Mutable and immutable bit arrays
description:
    Mutable and immutable bit arrays.
category: Data
author: Balazs Komuves
exposed: True
indefinite: False
exposed-modules:
    Data.BitArray Data.BitArray.IO Data.BitArray.ST
hidden-modules: Data.BitArray.Immutable
abi: b6ca693ab775f656f9fe86e520f0cd7a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/bitarray-0.0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/bitarray-0.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/bitarray-0.0.1.1
hs-libraries: HSbitarray-0.0.1.1-7aLvtv6Zt0Q3riGztsfTFs
depends:
    array-0.5.2.0 base-4.10.1.0
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-bitarray/html/bitarray.haddock
haddock-html: /usr/share/doc/haskell-bitarray/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bitarray-0.0.1.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bitarray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bitarray
version: 0.0.1.1
id: bitarray-0.0.1.1-VluIDj01KE7ojj4GIWFXd
key: bitarray-0.0.1.1-VluIDj01KE7ojj4GIWFXd
license: BSD-3-Clause
copyright: (c) 2009 Balazs Komuves
maintainer: bkomuves (plus) hackage (at) gmail (dot) com
author: Balazs Komuves
stability: Experimental
homepage: http://code.haskell.org/~bkomuves/
synopsis: Mutable and immutable bit arrays
description:
    Mutable and immutable bit arrays.
category: Data
abi: 32f12dbedb456134dc9472fc514d21f8
exposed: True
exposed-modules:
    Data.BitArray Data.BitArray.IO Data.BitArray.ST
hidden-modules: Data.BitArray.Immutable
import-dirs: /usr/lib/ghc-8.4.2/site-local/bitarray-0.0.1.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/bitarray-0.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/bitarray-0.0.1.1
hs-libraries: HSbitarray-0.0.1.1-VluIDj01KE7ojj4GIWFXd
depends:
    array-0.5.2.0 base-4.11.1.0
abi-depends: array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-bitarray/html/bitarray.haddock
haddock-html: /usr/share/doc/haskell-bitarray/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
